==> guildai-0.7.4-py2.py3-none-any.whl: guild/tests/uat/guild-check.md <==
 Guild check

Check:

    >>> run("guild check --offline")
    guild_version:             0.7.4...
    guild_install_location:    ...
    guild_home:                ...
    guild_resource_cache:      ...
    installed_plugins:         config_flags, cpu, dask, disk, exec_script, gpu, ipynb,
                               keras, memory, perf, python_script, queue, skopt
    python_version:            ...
    python_exe:                ...
    platform:                  ...
    psutil_version:            ...
    tensorboard_version:       ...
    cuda_version:              ...
    nvidia_smi_version:        ...
    latest_guild_version:      unchecked (offline)
    <exit 0>

Show more check info with the `-v` (verbose) option:

    >>> run("guild check -v --offline")
    guild_version:             ...
    ...
    click_version:             ...
    dask_version:              ...
    distutils_version:         ...
    numpy_version:             ...
    pandas_version:            not installed
    pip_version:               18.0
    sklearn_version:           ...
    skopt_version:             ...
    setuptools_version:        ...
    twine_version:             ...
    yaml_version:              ...
    werkzeug_version:          ...
    latest_guild_version:      unchecked (offline)
    <exit 0>

Show just env info:

    >>> run("guild check --offline --env")
    guild_version:             ...
    guild_install_location:    ...
    guild_home:                ...
    guild_resource_cache:      ...
    python_version:            ...
    python_exe:                ...
    latest_guild_version:      unchecked (offline)
    <exit 0>

TensorFlow info:

    >>> run("guild check --offline --tensorflow")
    guild_version:             ...
    tensorflow_version:        not installed
    ...
    <exit 0>

PyTorch info:

    >>> run("guild check --offline --pytorch")
    guild_version:             ...
    pytorch_version:           not installed
    ...
    <exit 0>

NOTE: twine version is not asserted because it's a test dep that isn't
always available when this test is run.

Show with disk usage:

    >>> run("guild check --offline --space")
    guild_version:             ...
    disk_space:
      guild_home:              ...
      runs:                    ...
      deleted_runs:            ...
      remote_state:            ...
      cache:                   ...
    <exit 0>

We should also see Guild environment files in our workspace:

    >>> run("cd $WORKSPACE && find .guild | LC_ALL=C sort")
    .guild
    .guild/.guild-nocopy
    .guild/cache
    .guild/cache/resources
    .guild/cache/runs
    .guild/runs
    .guild/trash
    <exit 0>

==> guildai-0.7.5-py2.py3-none-any.whl: guild/tests/uat/guild-check.md <==
 Guild check

Check:

    >>> run("guild check --offline")
    guild_version:             0.7.5...
    guild_install_location:    ...
    guild_home:                ...
    guild_resource_cache:      ...
    installed_plugins:         config_flags, cpu, dask, disk, dvc, exec_script, gpu,
                               ipynb, keras, memory, perf, python_script, queue, skopt
    python_version:            ...
    python_exe:                ...
    platform:                  ...
    psutil_version:            ...
    tensorboard_version:       ...
    cuda_version:              ...
    nvidia_smi_version:        ...
    latest_guild_version:      unchecked (offline)
    <exit 0>

Show more check info with the `-v` (verbose) option:

    >>> run("guild check -v --offline")
    guild_version:             ...
    ...
    click_version:             ...
    dask_version:              ...
    distutils_version:         ...
    numpy_version:             ...
    pandas_version:            not installed
    pip_version:               18.0
    sklearn_version:           ...
    skopt_version:             ...
    setuptools_version:        ...
    twine_version:             ...
    yaml_version:              ...
    werkzeug_version:          ...
    latest_guild_version:      unchecked (offline)
    <exit 0>

Show just env info:

    >>> run("guild check --offline --env")
    guild_version:             ...
    guild_install_location:    ...
    guild_home:                ...
    guild_resource_cache:      ...
    python_version:            ...
    python_exe:                ...
    latest_guild_version:      unchecked (offline)
    <exit 0>

TensorFlow info:

    >>> run("guild check --offline --tensorflow")
    guild_version:             ...
    tensorflow_version:        not installed
    ...
    <exit 0>

PyTorch info:

    >>> run("guild check --offline --pytorch")
    guild_version:             ...
    pytorch_version:           not installed
    ...
    <exit 0>

NOTE: twine version is not asserted because it's a test dep that isn't
always available when this test is run.

Show with disk usage:

    >>> run("guild check --offline --space")
    guild_version:             ...
    disk_space:
      guild_home:              ...
      runs:                    ...
      deleted_runs:            ...
      remote_state:            ...
      cache:                   ...
    <exit 0>

We should also see Guild environment files in our workspace:

    >>> run("cd $WORKSPACE && find .guild | LC_ALL=C sort")
    .guild
    .guild/.guild-nocopy
    .guild/cache
    .guild/cache/resources
    .guild/cache/runs
    .guild/runs
    .guild/trash
    <exit 0>
